@@ -25,6 +25,9 @@
    #include <termios.h>
 #endif
 
+BOOL Log_Dir_Normal( void );
+char * Get_Log_Dir( void );
+
 #define      ADD_COMMAND(a, b)     else if ( ! strcasecmp( tmp, a) )   \
           {                                                          \
               strncpy( b,strtok(NULL," \n\t"), 16 );                  \
@@ -181,6 +184,7 @@ password_entry:
    Contacts[ 1 ].port = 0;
    Contacts[ 1 ].sok = (SOK_T ) -1L;
    
+    strcpy(clear_cmd, "clear");
     strcpy(message_cmd, "msg");
     strcpy(info_cmd, "info");
     strcpy(add_cmd, "add");
@@ -241,6 +245,7 @@ static void Read_RC_File( FD_T rcf )
    char *tab_nick_spool[TAB_SLOTS];
    int spooled_tab_nicks;
    
+   clear_cmd[0]='\0';/* for error checking later */
    message_cmd[0]='\0';/* for error checking later */
    quit_cmd[0]='\0';   /* for error checking later */
    info_cmd[0]='\0';   /* for error checking later */
@@ -319,7 +324,9 @@ static void Read_RC_File( FD_T rcf )
 
          else if ( ! strcasecmp( tmp, "Russian" ) )
             {  Russian = TRUE; }
-         else if ( ! strcasecmp( tmp, "Hermit" ) )
+        else if ( ! strcasecmp( tmp, "JapaneseEUC" ) )
+           {  JapaneseEUC = TRUE; }
+          else if ( ! strcasecmp( tmp, "Hermit" ) )
             {  Hermit = TRUE; }
        else if ( ! strcasecmp( tmp, "LogType" ) )
                { LogType = atoi( strtok( NULL," \n\t" ) ); }
@@ -339,6 +346,7 @@ static void Read_RC_File( FD_T rcf )
             {  set_status = atoi( strtok( NULL, " \n\t" ) ); }
          else if ( ! strcasecmp( tmp, "Auto" ) )
             { auto_resp = TRUE; }
+         ADD_COMMAND( "clear_cmd", clear_cmd )
          ADD_COMMAND( "message_cmd", message_cmd )
          ADD_COMMAND( "info_cmd", info_cmd )
          ADD_COMMAND( "rand_cmd", rand_cmd )
@@ -356,10 +364,20 @@ static void Read_RC_File( FD_T rcf )
          ADD_MESS( "auto_rep_str_dnd", auto_rep_str_dnd )
          ADD_MESS( "auto_rep_str_occ", auto_rep_str_occ )
          ADD_MESS( "auto_rep_str_inv", auto_rep_str_inv )
+	 else if ( ! strcasecmp( tmp, "LogDir" ) ) {
+		Set_Log_Dir( strtok( NULL, "\n" ) );
+	 }
          else if ( ! strcasecmp( tmp, "Sound" ) ) {  
-            strcpy( Sound_Str, strtok( NULL, "\n\t" ) ); 
-            Sound = SOUND_CMD;
+            M_strcpy( Sound_Str, strtok( NULL, "\n\t" ) ); 
+	    if ( Sound_Str[0] ) {
+            	Sound = SOUND_CMD;
+	    } else {
+            	Sound = SOUND_OFF;
+	    }
          }
+	 else if ( ! strcasecmp( tmp, "No_Sound" ) ) {
+		Sound = SOUND_OFF;
+	 }
          else if ( ! strcasecmp( tmp, "Auto_away" ) )
             {  away_time = atoi( strtok( NULL, " \n\t" ) ); }
          else if ( ! strcasecmp( tmp, "Screen_width" ) )
@@ -421,7 +439,7 @@ static void Read_RC_File( FD_T rcf )
                Contacts[ Num_Contacts ].nick[0] = 0;
             if ( Contacts[ Num_Contacts ].nick[19] != 0 )
                Contacts[ Num_Contacts ].nick[19] = 0;
-            if ( Verbose )
+            if ( Verbose > 2 )
                M_print( "%ld = %s\n", Contacts[ Num_Contacts ].uin, Contacts[ Num_Contacts ].nick );
             Contacts[ Num_Contacts ].vis_list = FALSE;
             Num_Contacts++;
@@ -442,7 +460,7 @@ static void Read_RC_File( FD_T rcf )
                Contacts[ Num_Contacts ].nick[0] = 0;
             if ( Contacts[ Num_Contacts ].nick[19] != 0 )
                Contacts[ Num_Contacts ].nick[19] = 0;
-            if ( Verbose )
+            if ( Verbose > 2 )
                M_print( "%ld = %s\n", Contacts[ Num_Contacts ].uin, Contacts[ Num_Contacts ].nick );
             Contacts[ Num_Contacts ].invis_list = FALSE;
             Contacts[ Num_Contacts ].vis_list = TRUE;
@@ -464,7 +482,7 @@ static void Read_RC_File( FD_T rcf )
                Contacts[ Num_Contacts ].nick[0] = 0;
             if ( Contacts[ Num_Contacts ].nick[19] != 0 )
                Contacts[ Num_Contacts ].nick[19] = 0;
-            if ( Verbose )
+            if ( Verbose > 2 )
                M_print( "%ld = %s\n", Contacts[ Num_Contacts ].uin, Contacts[ Num_Contacts ].nick );
             Contacts[ Num_Contacts ].invis_list = TRUE;
             Contacts[ Num_Contacts ].vis_list = FALSE;
@@ -501,6 +519,8 @@ static void Read_RC_File( FD_T rcf )
       free( tab_nick_spool[i] );
    }
 
+   if(clear_cmd[0]=='\0')
+       strcpy(clear_cmd, "clear");
    if(message_cmd[0]=='\0')
        strcpy(message_cmd, "msg");
    if(update_cmd[0]=='\0')
@@ -603,18 +623,23 @@ int Save_RC()
    t = time( NULL );
    M_fdprint( rcf, "# This file was generated on %s", ctime( &t ) );   
    M_fdprint( rcf, "# Micq version " MICQ_VERSION );
-   M_fdprint( rcf, "\nUIN %d\n", UIN );
+   M_fdprint( rcf, "\n\nUIN %d\n", UIN );
+   M_fdprint( rcf, "# Remove the entire below line if you want to be prompted for your password.\n" );
    M_fdprint( rcf, "Password %s\n", passwd );
+   M_fdprint( rcf, "\n#Partial list of status you can use here.  (more from the change command )\n" );
+   M_fdprint( rcf, "#    0 Online\n" );
+   M_fdprint( rcf, "#   32 Free for Chat\n" );
+   M_fdprint( rcf, "#  256 Invisible\n" );
    M_fdprint( rcf, "Status %d\n", Current_Status );
-   M_fdprint( rcf, "Server %s\n", "icq1.mirabilis.com" );
+   M_fdprint( rcf, "\nServer %s\n", "icq1.mirabilis.com" );
    M_fdprint( rcf, "Port %d\n", 4000 );
 
 /* SOCKS5 stuff begin */
    M_fdprint( rcf, "\n# Support for SOCKS5 server\n" );
    M_fdprint( rcf, "s5_use %d\n", s5Use );
-  /* if ( NULL == s5Host )
+   if ( NULL == s5Host )
 	   M_fdprint( rcf, "s5_host [none]\n" );
-   else*/
+   else
 	   M_fdprint( rcf, "s5_host %s\n", s5Host );
    M_fdprint( rcf, "s5_port %d\n", s5Port );
    M_fdprint( rcf, "# If you need authentification, put 1 for s5_auth and fill your name/password\n" );
@@ -635,7 +660,12 @@ int Save_RC()
    else
       M_fdprint( rcf, "Hermit\n\n" );
 
-      M_fdprint( rcf, "# LogType defines if we log events to an individual file (per UIN),\n" );
+      M_fdprint( rcf, "# This is the location messages will be logged to\n" );
+      if ( Log_Dir_Normal() ) { 
+	M_fdprint( rcf, "#" );
+      }
+      M_fdprint( rcf, "LogDir %s\n", Get_Log_Dir() );
+      M_fdprint( rcf, "\n# LogType defines if we log events to an individual file (per UIN),\n" );
       M_fdprint( rcf, "# if we log everything to ~/micq.log or if we don't log at all.\n" );
       M_fdprint( rcf, "# Values are:\n# 0 - Don't Log\n" );
       M_fdprint( rcf, "# 1 - Log to ~/micq_log\n" );
@@ -657,9 +687,14 @@ int Save_RC()
    else
       M_fdprint( rcf, "No_Color\n" );
    if ( Russian )
-      M_fdprint( rcf, "\nRussian\n#if you want KOI8-R to CP1251 Russain translation uncomment the above line.\n" );
+      M_fdprint( rcf, "\nRussian\n#if you want KOI8-R/U to CP1251 Cyrillic translation uncomment the above line.\n" );
    else
-      M_fdprint( rcf, "\n#Russian\n#if you want KOI8-R to CP1251 Russain translation uncomment the above line.\n" );
+      M_fdprint( rcf, "\n#Russian\n#if you want KOI8-R/U to CP1251 Cyrillic translation uncomment the above line.\n" );
+  if( JapaneseEUC ) {
+    M_fdprint( rcf, "\nJapaneseEUC\n#if you want Shift-JIS <-> EUC Japanese translation uncomment the above line.\n" );
+  } else {
+    M_fdprint( rcf, "\n#JapaneseEUC\n#if you want Shift-JIS <-> EUC Japanese translation uncomment the above line.\n" );
+  }
    if ( auto_resp )
       M_fdprint( rcf, "\n#Automatic responses on.\nAuto\n" );
    else
@@ -670,6 +705,7 @@ int Save_RC()
 	M_fdprint( rcf, "\nScreen_Width %d\n", Max_Screen_Width );
 
    M_fdprint( rcf, "\n# Below are the commands which can be changed to most anything you want :)\n" );
+   M_fdprint( rcf, "clear_cmd %s\n",clear_cmd);
    M_fdprint( rcf, "message_cmd %s\n",message_cmd);
    M_fdprint( rcf, "togig_cmd %s\n",togig_cmd);
    M_fdprint( rcf, "iglist_cmd %s\n",iglist_cmd);
@@ -710,8 +746,8 @@ int Save_RC()
 
 
    M_fdprint( rcf, "\n# Ok now the contact list\n" );
-   M_fdprint( rcf, "#  Use * in front of the nickname of anyone you want to see you while you're invisble.\n" );
-   M_fdprint( rcf, "#  Use ~ in front of the nickname of anyone you want to always see you as offline.\n" );
+   M_fdprint( rcf, "#  Use * in front of the number of anyone you want to see you while you're invisble.\n" );
+   M_fdprint( rcf, "#  Use ~ in front of the number of anyone you want to always see you as offline.\n" );
    M_fdprint( rcf, "#  People in the second group won't show up in your list.\n" );
    M_fdprint( rcf, "Contacts\n" );
     /* adding contacts to the rc file. */
