@@ -121,7 +121,7 @@ BOOL Show_Short_String( BYTE **data, char *str )
 	 if ( len != 1 )
 	 {
 	 	(*data)[ len-1 ] = 0; /* be safe */
-                rus_conv( "wk", *data );
+                char_conv( "wc", *data );
 		 M_print( "%s%s",str, *data );
 	        *data += len;
                 return TRUE;
@@ -616,19 +616,19 @@ void Display_Info_Reply( int sok, BYTE * pak )
    
    M_print( SERVCOL "Info for %ld\n", Chars_2_DW( &pak[0] ) );
    len = Chars_2_Word( &pak[4] );
-   rus_conv( "wk", &pak[6] );
+   char_conv( "wc", &pak[6] );
    M_print( "Nick Name :\t%s\n", &pak[6] );
    tmp = &pak[6 + len ];
    len = Chars_2_Word( tmp );
-   rus_conv( "wk", tmp+2 );
+   char_conv( "wc", tmp+2 );
    M_print( "First name :\t%s\n", tmp+2 );
    tmp += len + 2;
    len = Chars_2_Word( tmp );
-   rus_conv( "wk", tmp+2 );
+   char_conv( "wc", tmp+2 );
    M_print( "Last name :\t%s\n", tmp+2 );
    tmp += len + 2;
    len = Chars_2_Word( tmp );
-   rus_conv( "wk", tmp+2 );
+   char_conv( "wc", tmp+2 );
    M_print( "Email Address :\t%s\n", tmp+2 );
    tmp += len + 2;
    if ( *tmp == 1 )
@@ -649,7 +649,7 @@ void Display_Ext_Info_Reply( int sok, BYTE * pak )
 
    M_print( SERVCOL "More Info for %ld\n", Chars_2_DW( &pak[0] ) );
    len = Chars_2_Word( &pak[4] );
-   rus_conv( "wk", &pak[6] );
+   char_conv( "wc", &pak[6] );
    M_print( "City         :\t%s\n", &pak[6] );
    if ( Get_Country_Name( Chars_2_Word(&pak[6+len]) ) != NULL )
       M_print( "Country      :\t%s\n",Get_Country_Name( Chars_2_Word(&pak[6+len]) ) );
@@ -658,7 +658,7 @@ void Display_Ext_Info_Reply( int sok, BYTE * pak )
    M_print( "Time Zone    :\tGMT %+d\n", ((signed char) pak[len+8])>>1  );
    tmp = &pak[9 + len ];
    len = Chars_2_Word( tmp );
-   rus_conv( "wk", tmp+2 );
+   char_conv( "wc", tmp+2 );
    M_print( "State        :\t%s\n", tmp+2 );
    if ( Chars_2_Word( tmp+2+len ) != 0xffff )
       M_print( "Age          :\t%d\n", Chars_2_Word( tmp+2+len ) );
@@ -676,15 +676,15 @@ void Display_Ext_Info_Reply( int sok, BYTE * pak )
 #endif
    tmp += len + 5;
    len = Chars_2_Word( tmp );
-   rus_conv( "wk", tmp+2 );
+   char_conv( "wc", tmp+2 );
    M_print( "Phone Number :\t%s\n", tmp+2 );
    tmp += len + 2;
    len = Chars_2_Word( tmp );
-   rus_conv( "wk", tmp+2 );
+   char_conv( "wc", tmp+2 );
    M_print( "Home Page    :\t%s\n", tmp+2 );
    tmp += len + 2;
    len = Chars_2_Word( tmp );
-   rus_conv( "wk", tmp+2 );
+   char_conv( "wc", tmp+2 );
    M_print( "About        :\n%s", tmp+2 );
 /*   ack_srv( sok, Chars_2_Word( pak.head.seq ) ); */
 }
@@ -695,19 +695,19 @@ void Display_Search_Reply( int sok, BYTE * pak )
    int len;
    M_print( SERVCOL "User found %ld\n", Chars_2_DW( &pak[0] ) );
    len = Chars_2_Word( &pak[4] );
-   rus_conv( "wk", &pak[6] );
+   char_conv( "wc", &pak[6] );
    M_print( "Nick Name :\t%s\n", &pak[6] );
    tmp = &pak[6 + len ];
    len = Chars_2_Word( tmp );
-   rus_conv( "wk", tmp+2 );
+   char_conv( "wc", tmp+2 );
    M_print( "First name :\t%s\n", tmp+2 );
    tmp += len + 2;
    len = Chars_2_Word( tmp );
-   rus_conv( "wk", tmp+2 );
+   char_conv( "wc", tmp+2 );
    M_print( "Last name :\t%s\n", tmp+2 );
    tmp += len + 2;
    len = Chars_2_Word( tmp );
-   rus_conv( "wk", tmp+2 );
+   char_conv( "wc", tmp+2 );
    M_print( "Email Address :\t%s\n", tmp+2 );
    tmp += len + 2;
    if ( *tmp == 1 )
@@ -729,23 +729,6 @@ void Do_Msg( SOK_T sok, DWORD type, WORD len, char * data, DWORD uin )
    char url_desc[1024];
 
    add_tab( uin );
-      /* aaron
-         If we just received a message from someone on the contact list,
-         save it with the person's contact information. If they are not in
-         the list, don't do anything special with it.                       */
-      if (UIN2Contact(last_recv_uin) != NULL) {
-          UIN2Contact(last_recv_uin)->LastMessage
-              = realloc(UIN2Contact(last_recv_uin)->LastMessage,
-                        len+5);
-          /* I add on so many characters because I always have segfaults in
-           my own program when I try to allocate strings like this. Somehow
-           it tries to write too much to the string even though I think I
-           allocate the right amount. Oh well. It shouldn't be too much
-           wasted space, I hope.                                            */
-          strcpy(UIN2Contact(last_recv_uin)->LastMessage, data);
-      }
-      /* end of aaron */
-
 
    if ( type == USER_ADDED_MESS )
    {
@@ -766,7 +749,7 @@ void Do_Msg( SOK_T sok, DWORD type, WORD len, char * data, DWORD uin )
          return;
       }
       *tmp = 0;
-      rus_conv ("wk",data);
+      char_conv ("wc",data);
       M_print( "First name    : " MESSCOL "%s" NOCOL "\n" , data );
       tmp++;
       data = tmp;
@@ -777,13 +760,13 @@ void Do_Msg( SOK_T sok, DWORD type, WORD len, char * data, DWORD uin )
          return;
       }
       *tmp = 0;
-      rus_conv ("wk",data);
+      char_conv ("wc",data);
       M_print( "Last name     : " MESSCOL "%s" NOCOL "\n" , data );
       tmp++;
       data = tmp;
       tmp = strchr( tmp, '\xFE' );
       *tmp = 0;
-      rus_conv ("wk",data);
+      char_conv ("wc",data);
       M_print( "Email address : " MESSCOL "%s" NOCOL "\n" , data );
    }
    else if ( type == AUTH_REQ_MESS )
@@ -800,7 +783,7 @@ void Do_Msg( SOK_T sok, DWORD type, WORD len, char * data, DWORD uin )
          return;
       }
       *tmp = 0;
-      rus_conv ("wk",data);
+      char_conv ("wc",data);
       M_print( "First name    : " MESSCOL "%s" NOCOL "\n" , data );
       tmp++;
       data = tmp;
@@ -811,7 +794,7 @@ void Do_Msg( SOK_T sok, DWORD type, WORD len, char * data, DWORD uin )
          return;
       }
       *tmp = 0;
-      rus_conv ("wk",data);
+      char_conv ("wc",data);
       M_print( "Last name     : " MESSCOL "%s" NOCOL "\n" , data );
       tmp++;
       data = tmp;
@@ -822,7 +805,7 @@ void Do_Msg( SOK_T sok, DWORD type, WORD len, char * data, DWORD uin )
          return;
       }
       *tmp = 0;
-      rus_conv ("wk",data);
+      char_conv ("wc",data);
       M_print( "Email address : " MESSCOL "%s" NOCOL "\n" , data );
       tmp++;
       data = tmp;
@@ -842,9 +825,40 @@ void Do_Msg( SOK_T sok, DWORD type, WORD len, char * data, DWORD uin )
          return;
       }
       *tmp = 0;
-      rus_conv ("wk",data);
+      char_conv ("wc",data);
       M_print( "Reason : " MESSCOL "%s" NOCOL "\n" , data );
    }
+   else if ((type == EMAIL_MESS )|| (type == WEB_MESS) ) {
+	tmp = strchr( data, '\xFE' );
+	*tmp = 0;
+	M_print( "\n%s ", data );
+	tmp++;
+	data=tmp;
+	tmp = strchr( data, '\xFE' );
+	tmp++;
+	data=tmp;
+
+        tmp = strchr( data, '\xFE' );
+        tmp++;
+	data= tmp;
+
+        tmp = strchr( data, '\xFE' );
+	*tmp = 0;
+        if ( type == EMAIL_MESS )
+		M_print("<%s> emailed you a message:\n", data);
+	else
+		M_print("<%s> send you a web message:\n", data);
+	tmp++;
+	data=tmp;
+	tmp = strchr( data, '\xFE' );
+	*tmp = 0;
+	if ( Verbose ) {
+		M_print( "??? '%s'\n", data );
+	}
+	tmp ++;
+	data=tmp;
+	M_print( MESSCOL "%s" NOCOL "\n", data );
+   }
    else if (type == URL_MESS || type == MRURL_MESS)
    {
 
@@ -855,11 +869,11 @@ void Do_Msg( SOK_T sok, DWORD type, WORD len, char * data, DWORD uin )
          return;
       }
       *tmp = 0;
-      rus_conv ("wk",data);
+      char_conv ("wc",data);
       strcpy (url_desc,data);
       tmp++;
       data = tmp;
-      rus_conv ("wk",data);
+      char_conv ("wc",data);
       strcpy (url_data,data);
       
       sprintf (message,"Description: %s \n                          URL: %s",url_desc,url_data);  
@@ -894,7 +908,7 @@ void Do_Msg( SOK_T sok, DWORD type, WORD len, char * data, DWORD uin )
 	}
    else
    {
-      rus_conv ("wk",data);
+      char_conv ("wc",data);
       if ( UIN2nick( uin ) != NULL )
          log_event( uin, LOG_MESS, "You received instant message from %s\n%s\n", UIN2nick(uin), data );
       else
@@ -902,4 +916,20 @@ void Do_Msg( SOK_T sok, DWORD type, WORD len, char * data, DWORD uin )
       M_print( MESSCOL "\n%s", data );
       M_print( NOCOL " " );
    }
+      /* aaron
+         If we just received a message from someone on the contact list,
+         save it with the person's contact information. If they are not in
+         the list, don't do anything special with it.                       */
+      if (UIN2Contact(last_recv_uin) != NULL) {
+          UIN2Contact(last_recv_uin)->LastMessage
+              = realloc(UIN2Contact(last_recv_uin)->LastMessage,
+                        len+5);
+          /* I add on so many characters because I always have segfaults in
+           my own program when I try to allocate strings like this. Somehow
+           it tries to write too much to the string even though I think I
+           allocate the right amount. Oh well. It shouldn't be too much
+           wasted space, I hope.                                            */
+          strcpy(UIN2Contact(last_recv_uin)->LastMessage, data);
+      }
+      /* end of aaron */
 }
