@@ -28,6 +28,10 @@
 #include "serbocroatian.h"
 #elif defined CROATIAN_LANG
 #include "croatian.h"
+#elif defined INDONESIAN_LANG
+#include "indonesian.h"
+#elif defined FINNISH_LANG
+#include "finnish.h"
 #else
 #error "Must select a language."
 #endif
