@@ -73,10 +73,14 @@ Changes :
 #include "beos.h"
 #endif
 
+DWORD real_packs_sent = 0;
+DWORD real_packs_recv = 0;
+
 BYTE Sound = SOUND_ON; /* Beeps on by default */
 BYTE Sound_Str[150];  /* the command to run from the shell to play sound files */
 BOOL Hermit = FALSE;
 BOOL Russian = FALSE; /* Do we do kio8-r <->Cp1251 codeset translation? */
+BOOL JapaneseEUC = FALSE; /* Do we do Shift-JIS <->EUC codeset translation? */
 BYTE LogType = 2; /* Currently 0 = no logging
 			       1 = old style ~/micq_log
 			       2 = new style ~/micq.log/uin.log
@@ -94,7 +98,7 @@ DWORD our_port; /* the port to make tcp connections on */
 /************ We don't make tcp connections yet though :( */
 DWORD UIN; /* current User Id Number */
 BOOL Contact_List = FALSE; /* I think we always have a contact list now */
-Contact_Member Contacts[ MAX_CONTACTS ]; /* no more than 100 contacts max */
+Contact_Member Contacts[ MAX_CONTACTS ]; /* no more than this many contacts max */
 int Num_Contacts=0;
 DWORD Current_Status=STATUS_OFFLINE;
 DWORD last_recv_uin=0;
@@ -107,12 +111,12 @@ BOOL Done_Login=FALSE;
 /* SOCKS5 stuff begin */
 int      s5Use;
 char     s5Host[100];
-unsigned short s5Port;
+WORD s5Port;
 int      s5Auth;
 char     s5Name[64];
 char     s5Pass[64];
-unsigned long  s5DestIP;
-unsigned short s5DestPort;
+DWORD  s5DestIP;
+WORD s5DestPort;
 /* SOCKS5 stuff end */
 
 BOOL auto_resp=FALSE;
@@ -121,6 +125,7 @@ char auto_rep_str_away[450] = { AWAY_DEFAULT_STR };
 char auto_rep_str_na[450] = { NA_DEFAULT_STR };
 char auto_rep_str_occ[450] = { OCC_DEFAULT_STR };
 char auto_rep_str_inv[450] = { INV_DEFAULT_STR };
+char clear_cmd[16];
 char message_cmd[16];
 char info_cmd[16];
 char quit_cmd[16];
@@ -162,14 +167,19 @@ unsigned int away_time;
 
 unsigned int next_resend;
 
-int tab_array[TAB_SLOTS];
+char * tab_array[TAB_SLOTS];
 int tab_pointer;
 
+/* aaron
+   Actual definition of the variable holding Micq's start time.				*/
+time_t	MicqStartTime;
+/* end of aaron */
+
 /*/////////////////////////////////////////////
 // Connects to hostname on port port
 // hostname can be DNS or nnn.nnn.nnn.nnn
 // write out messages to the FD aux */
-int Connect_Remote( char *hostname, int port, FD_T aux )
+SOK_T Connect_Remote( char *hostname, int port, FD_T aux )
 {
 /* SOCKS5 stuff begin */
    int res;
@@ -301,7 +311,7 @@ if( s5Use )
    sin.sin_addr.s_addr = inet_addr( hostname ); 
    if ( sin.sin_addr.s_addr  == -1 ) /* name isn't n.n.n.n so must be DNS */
    {
-	   host_struct = gethostbyname( hostname );/* name isn't n.n.n.n so must be DNS */
+	   host_struct = gethostbyname( hostname );
       if ( host_struct == NULL )
       {
          if ( Verbose )
@@ -317,15 +327,15 @@ if( s5Use )
    sin.sin_family = AF_INET; /* we're using the inet not appletalk*/
    sin.sin_port = ntohs (port);
 
-if( s5Use )
-{
-  s5DestIP = ntohl(sin.sin_addr.s_addr);
-  memcpy(&sin.sin_addr.s_addr, &buf[4], 4);
+	if( s5Use )
+	{
+	 s5DestIP = ntohl(sin.sin_addr.s_addr);
+	  memcpy(&sin.sin_addr.s_addr, &buf[4], 4);
   
-  sin.sin_family = AF_INET; /* we're using the inet not appletalk*/
-  s5DestPort = port;
-  memcpy(&sin.sin_port, &buf[8], 2);
-}
+	  sin.sin_family = AF_INET; /* we're using the inet not appletalk*/
+	  s5DestPort = port;
+	  memcpy(&sin.sin_port, &buf[8], 2);
+	}
 
    conct = connect( sok, (struct sockaddr *) &sin, sizeof( sin ) );
 
@@ -467,9 +477,12 @@ void Handle_Server_Response( SOK_T sok )
   /* !!! TODO make a check checksum routine to verify the packet further */
 /*   if ( ( serv_mess[ Chars_2_Word( pak.head.seq2 ) ] ) && 
       ( Chars_2_Word( pak.head.cmd ) != SRV_NEW_UIN ) )*/
-   if ( ( last_seq == Chars_2_DW( pak.head.seq ) ) && 
-      ( Chars_2_Word( pak.head.cmd ) != SRV_NEW_UIN ) )
+/*   if ( ( last_seq == Chars_2_DW( pak.head.seq ) ) && 
+      ( Chars_2_Word( pak.head.cmd ) != SRV_NEW_UIN ) ) */
+    if ( ( Chars_2_Word( pak.head.cmd ) != SRV_NEW_UIN ) &&
+	( Is_Repeat_Packet( Chars_2_Word( pak.head.seq ) ) ) )
     {
+      if ( Chars_2_Word( pak.head.seq ) == 0 ) {;} else {  /*yes ugly*/
       if ( Chars_2_Word( pak.head.cmd ) != SRV_ACK ) /* ACKs don't matter */
       {
          if ( Verbose ) {
@@ -480,12 +493,15 @@ void Handle_Server_Response( SOK_T sok )
          ack_srv( sok, Chars_2_DW( pak.head.seq ) ); /* LAGGGGG!! */
          return;
       }
+      }
    }
    if ( Chars_2_Word( pak.head.cmd ) != SRV_ACK )
    {
       serv_mess[ Chars_2_Word( pak.head.seq2 ) ] = TRUE;
       last_seq = Chars_2_DW( pak.head.seq );
+      Got_SEQ( Chars_2_DW( pak.head.seq ) );
       ack_srv( sok, Chars_2_DW( pak.head.seq ) );
+	real_packs_recv++;
    }
    Server_Response( sok, pak.head.check + DATA_OFFSET , s - ( sizeof( pak.head ) - 2 ), 
       Chars_2_Word( pak.head.cmd ), Chars_2_Word( pak.head.ver ),
@@ -602,8 +618,13 @@ int main( int argc, char *argv[] )
     because tab_array is initialized to zero (*somewhere*, but I can't find
     it). So we'll try initializing to -1 and see if it helps at all -- this
     way we can detect an early-exit condition.                              */
-   memset(tab_array, -1, TAB_SLOTS*sizeof(int));
+   memset(tab_array, 0, TAB_SLOTS*sizeof(int));
+
+   /* and now we save the time that Micq was started, so that uptime will be
+      able to appear semi intelligent.										*/
+   MicqStartTime = time(NULL);
    /* end of aaron */
+
    Set_rcfile( NULL );
    if (argc > 1 )
    {
@@ -615,9 +636,12 @@ int main( int argc, char *argv[] )
          {
             Verbose++;
          } else if ( (argv[i][1] == 'f' ) || (argv[i][1] == 'F' ) ) {
-		i++;
+		i++; /* skip the argument to f */
 		Set_rcfile( argv[i] );
 		M_print( "The config file for this session is \"%s\"\n", argv[i]);
+         } else if ( (argv[i][1] == 'l' ) || (argv[i][1] == 'L' ) ) {
+		i++;
+		M_print( "The logging directory for this session is \"%s\"\n", Set_Log_Dir( argv[i] ) );
 	 }
       }
    }
