@@ -19,8 +19,9 @@ Changes :
    2-26-99 Added TAB_SLOTS, tab_array, add_tab() and get_tab() (Lalo)
 **********************************************
 **********************************************/
-#define MICQ_VERSION "0.4.5 now with log file options.\t"
+#define MICQ_VERSION "0.4.6 now with word wrapping to fit the screen.\t"
 
+#include "config.h"
 #include "datatype.h"
 #include <stdlib.h>
 
@@ -80,13 +81,11 @@ Changes :
 #define STDOUT 1
 #define STDERR 2
 
-/* The maximum number of contacts to put in a single packet. */
-#define MAX_CONTS_PACKET 90
 
 /* The maximum number of contacts to store in the "last people
    I talked to" array (tab_array) */
 #define TAB_SLOTS 10
-extern int tab_array[TAB_SLOTS];
+extern char * tab_array[TAB_SLOTS];
 extern int tab_pointer;
 
 #if ICQ_VER == 0x0005
@@ -120,6 +119,7 @@ extern int tab_pointer;
 #define SEQ_OFFSET 16
 #define SEQ2_OFFSET 18
 #define DATA_OFFSET 4
+#define PAK_DATA_OFFSET 24
 
 #elif ICQ_VER == 0x0004
 
@@ -275,6 +275,8 @@ typedef struct
 #define USER_ADDED_MESS 0x000C
 #define AUTH_REQ_MESS 0x0006
 #define URL_MESS	0x0004
+#define WEB_MESS	0x000d
+#define EMAIL_MESS	0x000e
 #define MASS_MESS_MASK  0x8000
 #define MRURL_MESS	0x8004
 #define NORM_MESS		0x0001
@@ -507,7 +509,7 @@ int Save_RC();
 void User_Online( int sok, BYTE * pak );
 void M_fdprint( FD_T fd, char *str, ... );
 int M_fdnreadln( FD_T fd, char *buf, size_t len );
-char *Convert_Status_2_Str( int status );
+char *Convert_Status_2_Str( DWORD status );
 void Print_Status( DWORD new_status );
 void Get_Input( SOK_T sok , int *idle_val, int *idle_flag ); /* GRYN */
 void Quit_ICQ( SOK_T sok );
@@ -537,13 +539,13 @@ void start_search( SOK_T sok, char *email, char *nick, char* first, char* last )
 void Display_Search_Reply( int sok, BYTE * pak );
 /*int log_event(char    *desc,char    *msg,DWORD   uin);*/
 int log_event( DWORD uin, int type, char *str, ... );
-void rus_conv(char to[4],char *t_in);
+void char_conv(char *,char *);
 void clrscr(void);
 void reg_new_user( SOK_T sok, char *pass);
 void send_ext_info_req( SOK_T sok, DWORD uin );
 void Display_Ext_Info_Reply( int sok, BYTE * pak );
-const char *Get_Country_Name( int code );
-const char *Get_Lang_Name( int code );
+const char *Get_Country_Name( WORD code );
+const char *Get_Lang_Name( BYTE code );
 int Connect_Remote( char *hostname, int port, FD_T aux );
 void Update_More_User_Info( SOK_T sok, MORE_INFO_PTR user);
 void Update_User_Info( SOK_T sok, USER_INFO_PTR user);
@@ -576,6 +578,9 @@ void Update_About( SOK_T sok, const char *about );
 void Update_Other( SOK_T sok, OTHER_INFO_PTR info );
 void Print_Lang_Numbers( void );
 void Set_rcfile( char * name );
+void Got_SEQ( WORD this_seq );
+BOOL Is_Repeat_Packet( WORD this_seq );
+char * Set_Log_Dir( const char *newpath );
 
 extern Contact_Member Contacts[ MAX_CONTACTS ]; /* no more than 100 contacts max */
 extern int Num_Contacts;
@@ -616,6 +621,7 @@ extern char auto_rep_str_inv[450];
 extern char auto_rep_str_dnd[450];
 extern BYTE Sound_Str[150];
 extern BOOL Done_Login;
+extern char clear_cmd[16];
 extern char message_cmd[16];
 extern char info_cmd[16];
 extern char quit_cmd[16];
@@ -651,6 +657,7 @@ extern char togig_cmd[16];
 extern char iglist_cmd[16];
 
 extern BOOL Russian;
+extern BOOL JapaneseEUC;
 extern BOOL Logging;
 extern BOOL Color;
 
@@ -664,4 +671,14 @@ extern DWORD our_session;
 extern unsigned int away_time;
 extern BOOL Hermit;
 
-extern int Max_Screen_Width;
+extern WORD Max_Screen_Width;
+extern DWORD real_packs_sent;
+extern DWORD real_packs_recv;
+extern DWORD Packets_Sent;
+extern DWORD Packets_Recv;
+
+/* aaron
+   Variable to hold the time that Micq is started, for the "uptime" command,
+   which shows how long Micq has been running.                               */
+extern time_t MicqStartTime;
+/* end of aaron */
