@@ -23,6 +23,8 @@ Author : zed@mentasm.com
 #include "mreadline.h"
 
 /*unsigned int next_resend;*/
+DWORD Packets_Sent=0;
+DWORD Packets_Recv=0;
 
 DWORD our_session;
 
@@ -51,7 +53,7 @@ void Do_Resend( SOK_T sok )
     if ((queued_msg = msg_queue_pop()) != NULL)
     {
         queued_msg->attempts++;
-        if (queued_msg->attempts <= 6)
+        if (queued_msg->attempts <= MAX_RETRY_ATTEMPTS)
         {
             if ( Verbose )
             {
@@ -94,11 +96,11 @@ void Do_Resend( SOK_T sok )
                    if ( tmp != NULL )
                    {
                        *tmp = 0;
-                       rus_conv("wk", data);
+                       char_conv("wc", data);
                        strcpy(url_desc, data);
                        tmp++;
                        data = tmp;
-                       rus_conv("wk", data);
+                       char_conv("wc", data);
                        strcpy(url_data, data);
 
                        M_print( " Description: " MESSCOL "%s" \
@@ -109,7 +111,7 @@ void Do_Resend( SOK_T sok )
                }
                else if (type == NORM_MESS || type == MRNORM_MESS)
                {
-                   rus_conv("wk", data); 
+                   char_conv("wc", data); 
                    M_print( MESSCOL "%s", data );
                    M_print( NOCOL " " );
                }
@@ -217,7 +219,7 @@ void Update_About( SOK_T sok, const char *about )
    Word_2_Chars( pak.data, META_INFO_ABOUT );
    Word_2_Chars( &pak.data[2], strlen( about ) + 1 );
    strcpy( &pak.data[4], about );
-   rus_conv( "kw", &pak.data[4] );
+   char_conv( "cw", &pak.data[4] );
    pak.data[ strlen( about ) + 4 ] = 0; 
    last_cmd[ (seq_num - 1) & 0x3ff ] = Chars_2_Word( pak.head.cmd );
    SOCKWRITE( sok, &(pak.head.ver), sizeof( pak.head ) - 2 + 5 + strlen( about ) );
@@ -421,14 +423,14 @@ void Keep_Alive( int sok )
 
    if ( Verbose )
    {
-   R_undraw ();
+	   R_undraw ();
 #ifdef FUNNY_MSGS
-   M_print( "\nIf you go to" MESSCOL " Z'Ha'Dum " NOCOL "you will die!!!!\n" ); 
-   /* or if you don't send this packet */
+	   M_print("\nIf you go to"MESSCOL" Z'Ha'Dum "NOCOL"you will die!!\n"); 
+	   /* or if you don't send this packet */
 #else
-   M_print( "\nSend Keep_Alive packet to the server\n" );
+	   M_print( "\nSend Keep_Alive packet to the server\n" );
 #endif
-   R_redraw ();
+	   R_redraw ();
    }
 }
 
@@ -469,7 +471,7 @@ void icq_sendmsg( SOK_T sok, DWORD uin, char *text, DWORD msg_type)
 	else
            log_event( uin, LOG_MESS, "You sent instant message to %d\n%s\n", uin, text );
 
-	rus_conv ("kw",text);
+	char_conv ("cw",text);
 	
 	len = strlen(text);
 	Word_2_Chars( pak.head.ver, ICQ_VER );
@@ -893,62 +895,62 @@ void Update_More_User_Info( SOK_T sok, MORE_INFO_PTR user)
    size = 2;
    Word_2_Chars( pak.data + size, strlen( user->nick ) + 1 );
    size += 2;
-   rus_conv( "kw", user->nick );
+   char_conv( "cw", user->nick );
    strcpy( pak.data + size , user->nick );
    size += strlen( user->nick ) + 1;
    Word_2_Chars( pak.data + size, strlen( user->first ) + 1 );
    size += 2;
-   rus_conv( "kw", user->first );
+   char_conv( "cw", user->first );
    strcpy( pak.data + size , user->first );
    size += strlen( user->first ) + 1;
    Word_2_Chars( pak.data + size, strlen( user->last ) + 1);
    size += 2;
-   rus_conv( "kw", user->last );
+   char_conv( "cw", user->last );
    strcpy( pak.data + size , user->last );
    size += strlen( user->last ) +1 ;
    Word_2_Chars( pak.data + size, strlen( user->email ) + 1  );
    size += 2;
-   rus_conv( "kw", user->email );
+   char_conv( "cw", user->email );
    strcpy( pak.data + size , user->email );
    size += strlen( user->email ) + 1;
    Word_2_Chars( pak.data + size, strlen( user->email2 ) + 1  );
    size += 2;
-   rus_conv( "kw", user->email2 );
+   char_conv( "cw", user->email2 );
    strcpy( pak.data + size , user->email2 );
    size += strlen( user->email2 ) + 1;
    Word_2_Chars( pak.data + size, strlen( user->email3 ) + 1  );
    size += 2;
-   rus_conv( "kw", user->email3 );
+   char_conv( "cw", user->email3 );
    strcpy( pak.data + size , user->email3 );
    size += strlen( user->email3 ) + 1;
    Word_2_Chars( pak.data + size, strlen( user->city ) + 1  );
    size += 2;
-   rus_conv( "kw", user->city );
+   char_conv( "cw", user->city );
    strcpy( pak.data + size , user->city );
    size += strlen( user->city ) + 1;
    Word_2_Chars( pak.data + size, strlen( user->state ) + 1  );
    size += 2;
-   rus_conv( "kw", user->state );
+   char_conv( "cw", user->state );
    strcpy( pak.data + size , user->state );
    size += strlen( user->state ) + 1;
    Word_2_Chars( pak.data + size, strlen( user->phone ) + 1  );
    size += 2;
-   rus_conv( "kw", user->phone );
+   char_conv( "cw", user->phone );
    strcpy( pak.data + size , user->phone );
    size += strlen( user->phone ) + 1;
    Word_2_Chars( pak.data + size, strlen( user->fax ) + 1  );
    size += 2;
-   rus_conv( "kw", user->fax );
+   char_conv( "cw", user->fax );
    strcpy( pak.data + size , user->fax );
    size += strlen( user->fax ) + 1;
    Word_2_Chars( pak.data + size, strlen( user->street ) + 1  );
    size += 2;
-   rus_conv( "kw", user->street );
+   char_conv( "cw", user->street );
    strcpy( pak.data + size , user->street );
    size += strlen( user->street ) + 1;
    Word_2_Chars( pak.data + size, strlen( user->cellular ) + 1  );
    size += 2;
-   rus_conv( "kw", user->cellular );
+   char_conv( "cw", user->cellular );
    strcpy( pak.data + size , user->cellular );
    size += strlen( user->cellular ) + 1;
    DW_2_Chars( &pak.data[ size ] , user->zip );
@@ -1078,6 +1080,7 @@ size_t SOCKWRITE( SOK_T sok, void * ptr, size_t len )
 #endif
    cmd = Chars_2_Word( (((ICQ_PAK_PTR)((BYTE*)ptr-2))->cmd ) );
    if ( cmd != CMD_ACK ) {
+	real_packs_sent++;
       msg_to_queue = (struct msg *) malloc(sizeof(struct msg));
 #if ICQ_VER == 0x0004
       msg_to_queue->seq = Chars_2_Word( &((BYTE *)ptr)[SEQ_OFFSET] );
@@ -1141,7 +1144,7 @@ assert( len > 0x18 );
          Hex_Dump( ptr, len );
 #endif 
 /*   Dump_Queue()*/
-
+Packets_Sent++;
 /* SOCKS5 stuff begin */
 if( s5Use )
 {
@@ -1164,7 +1167,7 @@ size_t SOCKREAD( SOK_T sok, void * ptr, size_t len )
    size_t sz;
    
    sz = sockread( sok, ptr, len );
-
+   Packets_Recv++;
 /* SOCKS5 stuff begin */
 if( s5Use )
 {
