@@ -12,6 +12,7 @@ Contributors : Nicolas Sahlqvist April 27, 1998
                Michael Ivey May 4, 1998
                Ulf Hedlund -- Windows Support
                Michael Holzt May 5, 1998
+			   aaron March 29, 2000
 Changes :
 22-6-98 Added the save and alter command and the
         new implementation of auto
@@ -44,6 +45,8 @@ Changes :
 #include <ctype.h>
 #include <assert.h>
 #include "ui.h"
+#include "util_ui.h"	/* aaron -- to get access to Get_Max_Screen_Width()
+						   function	*/
 
 #ifdef __BEOS__
 #include "beos.h"
@@ -56,6 +59,114 @@ char *strdup( const char * );
 int strcasecmp( const char *, const char * );
 #endif
 
+/* aaron
+   Displays the Contact List in a wide format, similar to the ls command.	*/
+void PrintContactWide() {
+	int		*Online;  /* definitely won't need more; could	*/
+	int		*Offline; /* probably get away with less.	*/
+	int		MaxLen = 0;	/* legnth of longest contact name */
+	int		i;
+	int		OnIdx = 0;		/* for inserting and tells us how many there are*/
+	int		OffIdx = 0;		/* for inserting and tells us how many there are*/
+	int		NumCols;		/* number of columns to display on screen		*/
+	int		Col;			/* the current column during output.			*/
+
+	if ((Online = (int *)malloc(Num_Contacts * sizeof(int))) == NULL) {
+		M_print("Insuffificient memory to display a wide Contact List.\n");
+		return;
+	}  /* end if */
+
+	if ((Offline = (int *)malloc(Num_Contacts * sizeof(int))) == NULL) {
+		M_print("Insuffificient memory to display a wide Contact List.\n");
+		return;
+	}  /* end if */
+
+	/* We probably don't need to zero out the array, but just to be on the
+		safe side...
+		The arrays really should be only Num_Contacts in size... future
+		improvement, I guess. Hopefully no one is running that tight on
+		memory.																*/
+	memset(Online, 0, sizeof(Online));
+	memset(Offline, 0, sizeof(Offline));
+
+	/* Filter the contact list into two lists -- online and offline. Also
+		find the longest name in the list -- this is used to determine how
+		many columns will fit on the screen.								*/
+	for (i = 0; i < Num_Contacts; i++) {
+		if ( (S_DWORD) Contacts[i].uin > 0 ) { /* Aliases */
+			if (Contacts[i].status == STATUS_OFFLINE)
+				Offline[OffIdx++] = i;
+			else
+				Online[OnIdx++] = i;
+	
+			if (strlen(Contacts[i].nick) > MaxLen)
+				MaxLen = strlen(Contacts[i].nick);
+		}
+	}  /* end for */
+
+	/* This is probably a very ugly way to determine the number of columns
+		to use... it's probably specific to my own contact list.			*/
+	NumCols = Get_Max_Screen_Width() / (MaxLen+4);
+	if (NumCols < 1)
+		NumCols = 1;		/* sanity check. :)  */
+	
+	/* Fairly simple print routine. We check that we only print the right
+		number of columns to the screen.									*/
+	M_print(MESSCOL );
+	for ( i = 1; i < ( Get_Max_Screen_Width() - strlen( "Offline" ) ) / 2 ; i++ ) { M_print( "=" ); }
+	M_print( CLIENTCOL "Offline" MESSCOL);
+	for ( i = 1; i < ( Get_Max_Screen_Width() - strlen( "Offline" ) ) / 2 ; i++ ) { M_print( "=" ); }
+	M_print( NOCOL "\n" );
+	for (Col = 1, i = 0; i < OffIdx; i++)
+		if (Col % NumCols == 0) {
+			M_print(CONTACTCOL "  %-*s\n" NOCOL, MaxLen+2, 
+					Contacts[Offline[i]].nick);
+			Col = 1;
+		} else {
+			M_print(CONTACTCOL "  %-*s" NOCOL, MaxLen+2, 
+					Contacts[Offline[i]].nick);
+			Col++;
+		}  /* end if */
+
+	/* The user status for Online users is indicated by a one-character
+		prefix to the nickname. Unfortunately not all statuses (statusae? :)
+		are unique at one character. A better way to encode the information
+		is needed.															*/
+	if ( (Col-1) % NumCols != 0) { M_print( "\n" ); }
+	M_print(MESSCOL );
+	for ( i = 1; i < ( Get_Max_Screen_Width() - strlen( "Online" ) ) / 2 ; i++ ) { M_print( "=" ); }
+	M_print( CLIENTCOL "Online" MESSCOL);
+	for ( i = 1; i < ( Get_Max_Screen_Width() - strlen( "Online" ) ) / 2 ; i++ ) { M_print( "=" ); }
+	M_print( NOCOL "\n" );
+	for (Col = 1, i = 0; i < OnIdx; i++) {
+		char *status;
+		char weird = 'W'; /* for weird statuses that are reported as hex */
+
+		status = Convert_Status_2_Str(Contacts[Online[i]].status);
+		status = status ? status : &weird;
+		if ( ( Contacts[Online[i]].status & 0xfff) == STATUS_ONLINE ) {
+			status = " ";
+		}
+		if (Col % NumCols == 0) {
+			M_print(NOCOL "%c " CONTACTCOL "%-*s\n" NOCOL, 
+			/*		*Convert_Status_2_Str(Contacts[Online[i]].status), */ *status,
+					MaxLen+2, Contacts[Online[i]].nick);
+			Col = 1;
+		} else {
+			M_print(NOCOL "%c " CONTACTCOL "%-*s" NOCOL, 
+/*					*Convert_Status_2_Str(Contacts[Online[i]].status), */ *status,
+					MaxLen+2, Contacts[Online[i]].nick);
+			Col++;
+		}  /* end if */
+	}
+	if ( (Col-1) % NumCols != 0) { M_print( "\n" ); }
+	M_print( MESSCOL );
+	for ( i = 1; i < Get_Max_Screen_Width() - 1 ; i++ ) { M_print( "=" ); }
+	M_print( NOCOL "\n" );
+	free(Online);
+	free(Offline);
+}  /* end of aaron */
+
 BOOL Do_Multiline( SOK_T sok, char *buf )
 {
    static int offset=0;
@@ -102,6 +213,10 @@ BOOL Do_Multiline( SOK_T sok, char *buf )
    }
 }
 
+/***************************************************************************
+This function gathers information for the other info update packet
+age sex d.o.b. etc.
+****************************************************************************/
 void Info_Other_Update( SOK_T sok, char * buf)
 {
 	static OTHER_INFO_STRUCT other;
@@ -183,6 +298,10 @@ void Info_Other_Update( SOK_T sok, char * buf)
 	}
 }
 
+/***************************************************************************
+This function gathers information for the main info update packet
+name email etc
+****************************************************************************/
 void Info_Update( SOK_T sok, char *buf )
 {
  
@@ -268,10 +387,10 @@ void Info_Update( SOK_T sok, char *buf )
       {
          user.auth = FALSE;
          Update_More_User_Info( sok, &user );
-/*         free( user.nick );
+         free( user.nick );
          free( user.last );
          free( user.first );
-         free( user.email ); */
+         free( user.email ); 
          status = 0;
       }
       else if ( ! strcasecmp( buf, YES_STR ) )
@@ -293,6 +412,9 @@ void Info_Update( SOK_T sok, char *buf )
    }
 }
 
+/**************************************************************************
+Multi line about info updates
+**************************************************************************/
 BOOL About_Info( SOK_T sok, char *buf )
 {
    static int offset=0;
@@ -328,6 +450,9 @@ BOOL About_Info( SOK_T sok, char *buf )
    }
 }
 
+/**************************************************************************
+Gets the info to search for a user by
+***************************************************************************/
 void User_Search( SOK_T sok, char *buf )
 {
 	switch (status) {
@@ -359,6 +484,9 @@ void User_Search( SOK_T sok, char *buf )
 	}
 }
 
+/**************************************************************************
+Messages everyone in the conact list
+***************************************************************************/
 BOOL Do_Multiline_All( SOK_T sok, char *buf )
 {
    static int offset=0;
@@ -409,6 +537,8 @@ BOOL Do_Multiline_All( SOK_T sok, char *buf )
 
 /******************************************************
 Read a line of input and processes it.
+
+This is huge and ugly it should be fixed.
 *******************************************************/
 void Get_Input( SOK_T sok , int *idle_val, int *idle_flag ) /* GRYN */
 {
@@ -470,7 +600,11 @@ void Get_Input( SOK_T sok , int *idle_val, int *idle_flag ) /* GRYN */
         if ( '!' == buf[0] )
         {
 	   R_pause ();
+#ifdef SHELL_COMMANDS
 	   system( &buf[1] );
+#else
+	  M_print( "Shell commands have been disabled.\n" );
+#endif
 	   R_resume ();
            Prompt();
            return;
@@ -536,13 +670,13 @@ void Get_Input( SOK_T sok , int *idle_val, int *idle_flag ) /* GRYN */
 	      else if ( ! strcasecmp( cmd, away_cmd ) ) /* away command */
                  {   /* GRYN */ *idle_flag = 0;
 	             CHANGE_STATUS( STATUS_AWAY ); }
-	      else if ( ! strcasecmp( cmd, na_cmd ) ) /* Not Available command */
+	      else if ( ! strcasecmp( cmd, na_cmd ) ) /* Not Available command*/
    	         {   /* GRYN */ *idle_flag = 0;
                      CHANGE_STATUS( STATUS_NA ); }
 	      else if ( ! strcasecmp( cmd, occ_cmd ) ) /* Occupied command */
                  {   /* GRYN */ *idle_flag = 0;
 	             CHANGE_STATUS( STATUS_OCCUPIED ); }
-	      else if ( ! strcasecmp( cmd, dnd_cmd ) ) /* Do not Disturb  command */
+	      else if ( ! strcasecmp( cmd, dnd_cmd ) ) /* Do not Disturb command */
               {   /* GRYN */ *idle_flag = 0;
    	          CHANGE_STATUS( STATUS_DND ); }
 	      else if ( ! strcasecmp( cmd, ffc_cmd ) ) /* Free For Chat command */
@@ -615,7 +749,7 @@ void Get_Input( SOK_T sok , int *idle_val, int *idle_flag ) /* GRYN */
          }
          else if ( ! strcasecmp( cmd, again_cmd ) ) /* again command */
          {  Again_Function( sok ); }
-         else if ( ! strcasecmp( cmd, "clear"))
+         else if ( ! strcasecmp( cmd, clear_cmd))
    	   { /* GRYN */ *idle_val = idle_save; 
              clrscr(); }
          else if ( ! strcasecmp( cmd, info_cmd ) )
@@ -816,11 +950,23 @@ void Get_Input( SOK_T sok , int *idle_val, int *idle_flag ) /* GRYN */
               for every unused tab position. This isn't really a problem,
               it just looks a little messy.                                 */
             M_print("Last %d people you talked to:\n", TAB_SLOTS);
-            for (i = 0; (i < TAB_SLOTS) && (tab_array[i] != -1); i++)
+            for (i = 0; (i < TAB_SLOTS) && (tab_array[i] != NULL); i++)
             {
-               M_print("   %s%s%s (now ", CONTACTCOL, Contacts[tab_array[i]].nick, MESSCOL);
-               Print_Status( Contacts[tab_array[i]].status );
-               M_print(")%s\n", NOCOL);
+               DWORD temp_uin;
+               CONTACT_PTR cont;
+               temp_uin = nick2uin( tab_array[i] );
+               M_print("   " );
+               Print_UIN_Name( temp_uin );
+               cont = UIN2Contact( temp_uin );
+               if ( NULL != cont ) {
+                  M_print( MESSCOL " (now " );
+                  Print_Status(  cont->status );
+                  M_print( ")" NOCOL );
+               }
+               M_print( "\n" );
+/*               M_print("   %s%s%s (now ", CONTACTCOL, Contacts[tab_array[i]].nick, MESSCOL);
+               Print_Status( tab_array[i] );
+               M_print(")%s\n", NOCOL);*/
             }
          }
         /* aaron
@@ -835,7 +981,17 @@ void Get_Input( SOK_T sok , int *idle_val, int *idle_flag ) /* GRYN */
          {
              arg1 = strtok(NULL, "\t\n");  /* Is this right? */
              if (arg1 == NULL) {
-                 M_print("Must specify: last message from whom?\n");
+			 	int		i;
+
+#ifdef FUNNY_MSGS
+				M_print("These people are being sociable today:\n");
+#else
+				M_print("You have received messages from:\n");
+#endif
+				for (i = 0; i < Num_Contacts; i++) {
+					if (Contacts[i].LastMessage != NULL)
+						M_print(CONTACTCOL "  %s\n" NOCOL, Contacts[i].nick);
+				}  /* end if */
              } else {
                  if ((uin = nick2uin(arg1)) == -1) {
                      M_print("Unknown Contact: %s\n", arg1);
@@ -847,11 +1003,48 @@ void Get_Input( SOK_T sok , int *idle_val, int *idle_flag ) /* GRYN */
                                  UIN2Contact(uin)->LastMessage);
                          M_print(NOCOL " \n");
                      } else {
-                         M_print("No messages received from %s\n",
-                                 UIN2Contact(uin)->nick);
+#ifdef FUNNY_MSGS
+						 M_print(CONTACTCOL "%s" NOCOL " hasn't had anything "
+						 		 "intelligent to say today.\n", 
+								 UIN2Contact(uin)->nick);
+#else
+                         M_print("No messages received from " CONTACTCOL
+						 		 "%s\n" NOCOL, UIN2Contact(uin)->nick);
+#endif
                      }
                  }
              }
+		 } else if (strcasecmp(cmd, "uptime") == 0) {
+		 	double	TimeDiff = difftime(time(NULL), MicqStartTime);
+			int		Days, Hours, Minutes, Seconds;
+
+			Seconds = (int)TimeDiff % 60;
+			TimeDiff = TimeDiff / 60.0;
+			Minutes = (int)TimeDiff % 60;
+			TimeDiff = TimeDiff / 60.0;
+			Hours = (int)TimeDiff % 24;
+			TimeDiff = TimeDiff / 24.0;
+			Days = TimeDiff;
+
+			M_print("Micq has been running for ");
+			if (Days != 0)
+				M_print(MESSCOL "%02d " NOCOL "days, ", Days);
+			if (Hours != 0)
+				M_print(MESSCOL "%02d " NOCOL "hours, ", Hours);
+			if (Minutes != 0)
+				M_print(MESSCOL "%02d " NOCOL "minutes, ", Minutes);
+			M_print(MESSCOL "%02d " NOCOL "seconds.\n", Seconds);
+			M_print( "Contacts " MESSCOL "%d" NOCOL " / %d\n",Num_Contacts ,MAX_CONTACTS );
+			M_print( "Packets Sent : " MESSCOL );
+			M_print( "%d" NOCOL "\tPackets Recieved : " MESSCOL "%d" NOCOL "\t", Packets_Sent, Packets_Recv );
+			if ( Packets_Sent | Packets_Recv ) {
+				M_print( "Lag : " MESSCOL );
+				M_print( "%2.2f" NOCOL " %%\n", abs( Packets_Sent - Packets_Recv ) * ( 200.0 / ( Packets_Sent + Packets_Recv ) ) );
+			}
+			M_print( "Distinct Packets Sent : " MESSCOL );
+			M_print( "%d" NOCOL "\tDistinct Packets Recieved : " MESSCOL "%d" NOCOL "\n", real_packs_sent, real_packs_recv );
+		 } else if (strcasecmp(cmd, "wide") == 0) {
+		 	PrintContactWide();
          } /* end of aaron's code */
          else 
          {  M_print( UNKNOWN_COMMAND_STR "\n", cmd ); }
@@ -1233,7 +1426,7 @@ static void Help_Function( void )
        M_print( ACCOUNT_CAT_STR "\t-\t" ACCOUNT_HELP_STR "\n" );
    } else if ( !strcasecmp( arg1, CLIENT_CAT_STR ) ){
 	    M_print( MESSCOL "verbose #" NOCOL VERBOSE_HELP_STR);
-            M_print( MESSCOL "clear" NOCOL CLEAR_HELP_STR );
+            M_print( MESSCOL "%s" NOCOL CLEAR_HELP_STR, clear_cmd );
             M_print( MESSCOL "%s" NOCOL SOUND_HELP_STR, sound_cmd);
             M_print( MESSCOL "%s" NOCOL COLOR_HELP_STR, color_cmd);
             M_print( MESSCOL "%s\t" NOCOL QUIT_HELP_STR,quit_cmd );
@@ -1251,6 +1444,8 @@ static void Help_Function( void )
             M_print( MESSCOL "%s <message>" NOCOL AGAIN_HELP_STR, again_cmd);
             M_print( MESSCOL "%s <message>" NOCOL REPLY_HELP_STR, reply_cmd);
             M_print( MESSCOL "%s <nick>" NOCOL LAST_HELP_STR, "last");
+            M_print( MESSCOL "uptime\t\tShows how long Micq has been "
+					"running.\n" NOCOL);
 	    M_print( CLIENTCOL "\tuin can be either a number or the nickname of the user.\n" );
             M_print( CLIENTCOL "\tSending a blank message will put the client into multiline mode.\n\tUse . on a line by itself to end message.\n" );
 	    M_print( "\tUse # on a line by itself to cancel the message." NOCOL "\n" );
