@@ -44,6 +44,9 @@ Changes :
    #include "mreadline.h"
 #endif
 
+static char *Log_Dir = NULL;
+static BOOL Normal_Log = TRUE;
+
 typedef struct 
 {
    const char *name;
@@ -322,7 +325,7 @@ static COUNTRY_CODE Country_Codes[] = { { USA_COUNTRY_STR, 1 },
 #endif
 
 
-const char *Get_Country_Name( int code )
+const char *Get_Country_Name( WORD code )
 {
    int i;
    
@@ -342,7 +345,7 @@ const char *Get_Country_Name( int code )
 
 
 
-const char *Get_Lang_Name( int code )
+const char *Get_Lang_Name( BYTE code )
 {
    int i;
    
@@ -380,7 +383,7 @@ void Print_Lang_Numbers( void )
 returns a string describing the status or
 a NULL if no such string exists
 *********************************************/
-char *Convert_Status_2_Str( int status )
+char *Convert_Status_2_Str( DWORD status )
 {
    if ( STATUS_OFFLINE == status ) /* this because -1 & 0xFFFF is not -1 */
    {
@@ -728,7 +731,7 @@ DWORD Get_Port( DWORD uin )
 Converts an intel endian character sequence to
 a DWORD
 *********************************************/
-DWORD Chars_2_DW( unsigned char *buf )
+DWORD Chars_2_DW( BYTE *buf )
 {
    DWORD i;
    
@@ -747,7 +750,7 @@ DWORD Chars_2_DW( unsigned char *buf )
 Converts an intel endian character sequence to
 a WORD
 *********************************************/
-WORD Chars_2_Word( unsigned char *buf )
+WORD Chars_2_Word( BYTE *buf )
 {
    WORD i;
    
@@ -762,7 +765,7 @@ WORD Chars_2_Word( unsigned char *buf )
 Converts a DWORD to
 an intel endian character sequence 
 *********************************************/
-void DW_2_Chars( unsigned char *buf, DWORD num )
+void DW_2_Chars( BYTE *buf, DWORD num )
 {
    buf[3] = ( unsigned char ) ((num)>>24)& 0x000000FF;
    buf[2] = ( unsigned char ) ((num)>>16)& 0x000000FF;
@@ -774,12 +777,76 @@ void DW_2_Chars( unsigned char *buf, DWORD num )
 Converts a WORD to
 an intel endian character sequence 
 *********************************************/
-void Word_2_Chars( unsigned char *buf, WORD num )
+void Word_2_Chars( BYTE *buf, WORD num )
 {
    buf[1] = ( unsigned char ) (((unsigned)num)>>8) & 0x00FF;
    buf[0] = ( unsigned char ) ((unsigned)num) & 0x00FF;
 }
 
+BOOL Log_Dir_Normal( void )
+{
+	return Normal_Log;
+}
+
+/************************************************************************
+Sets the Log directory to newpath 
+if newpath is null it will set it to a reasonable default
+if newpath doesn't end with a valid directory seperator one is added.
+the path used is returned.
+*************************************************************************/
+char * Set_Log_Dir( const char *newpath )
+{
+	if ( NULL == newpath ) {
+	   char *path;
+	   char *home;
+	   Normal_Log = TRUE;
+#ifdef _WIN32
+	   path = ".\\";
+#endif
+
+#ifdef UNIX
+	   home = getenv( "HOME" );
+	   path = malloc( strlen( home ) + 2 );
+	   strcpy( path, home );
+	   if ( path[ strlen( path ) - 1 ] != '/' )
+	      strcat( path, "/" );
+#endif
+
+#ifdef __amigaos__
+	   path = "PROGDIR:";
+#endif
+		Log_Dir = path;
+		return path;
+	} else {
+#ifdef _WIN32
+		char sep = '\\';
+#else
+		char sep = '/';
+#endif
+		Normal_Log=FALSE;
+		if ( newpath[ strlen( newpath ) - 1 ] != sep ) {
+			Log_Dir = malloc( strlen( newpath ) + 2 );
+			sprintf( Log_Dir, "%s%c", newpath, sep );
+		} else {
+			Log_Dir = strdup( newpath );
+		}
+		return Log_Dir;
+	}
+}
+
+/************************************************************************
+Returns the current directory used for logging.  If none has been 
+specified it sets it tobe a reasonable default (~/)
+*************************************************************************/
+char * Get_Log_Dir( void )
+{
+	if ( NULL == Log_Dir ) {
+		return Set_Log_Dir( NULL );
+	} else {
+		return Log_Dir;
+	}
+}
+
 /*************************************************************************
  *      Function: log_event
  *      Purpose: Log the event provided to the log with a time stamp.
@@ -788,14 +855,15 @@ void Word_2_Chars( unsigned char *buf, WORD num )
  *************************************************************************/
 int log_event( DWORD uin, int type, char *str, ... )
 {
+   char symbuf[256]; /* holds the path for a sym link */
    FILE    *msgfd;
    va_list args;
    int k;
-   char buf[2048]; /* this should big enough */
+   char buf[2048]; /* this should big enough - This holds the message to be logged */
    char    buffer[256];
    time_t  timeval;
    char *path;
-   char *home;
+/*   char *home; */
    struct stat statbuf;
 
    if ( ! LogType )
@@ -809,7 +877,7 @@ int log_event( DWORD uin, int type, char *str, ... )
    sprintf( buf, "\n%-24.24s ", ctime(&timeval) );
    vsprintf( &buf[ strlen( buf ) ], str, args );
 
-      
+/*************************************************      
 #ifdef _WIN32
    path = ".\\";
 #endif
@@ -827,6 +895,11 @@ int log_event( DWORD uin, int type, char *str, ... )
 #endif
 
    strcpy( buffer, path );
+*************************************************/
+
+   path = Get_Log_Dir();
+   strcpy( buffer, path );
+
 switch (LogType) {
 	case 1:
 		strcat(buffer,"micq_log");
@@ -847,13 +920,22 @@ switch (LogType) {
 #else
   	 strcat( buffer, "/" );
 #endif
+		strcpy( symbuf, buffer);
 	   sprintf( &buffer[ strlen( buffer ) ], "%ld.log", uin );
+      
+#ifdef UNIX
+	if ( NULL != UIN2nick(uin) ) {
+     		 sprintf( &symbuf[strlen(symbuf)],"%s.log",UIN2nick(uin) );
+	      symlink(buffer,symbuf);
+	}
+#endif        
+       
 
 	   break;
 }
    if( ( msgfd = fopen(buffer, "a") ) == (FILE *) NULL ) 
    {
-           fprintf(stderr, "Couldn't open %s for logging\n",
+           fprintf(stderr, "\nCouldn't open %s for logging\n",
                             buffer);
            return(-1);
    }
@@ -862,18 +944,21 @@ switch (LogType) {
     else
        fprintf(msgfd, "\n%-24.24s %s %s\n%s\n", ctime(&timeval), desc, UIN2nick(uin), msg);*/
 
-   k = fwrite( buf, 1, strlen( buf ), msgfd );
-   if ( k != strlen( buf ) )
-   {
-       perror( "Log file write error" );
-      return -1;
+   if ( strlen( buf ) ) {
+   	fwrite( "<", 1, 1, msgfd );
+   	k = fwrite( buf, 1, strlen( buf ), msgfd );
+   	if ( k != strlen( buf ) )
+   	{
+       		perror( "\nLog file write error\n" );
+      		return -1;
+   	}
+   	fwrite( ">\n", 1, 2, msgfd );
    }
    va_end( args );
      
    fclose(msgfd);
 #ifdef UNIX
    chmod( buffer, 0600 );
-   free( path );
 #endif
    return(0);
 }
@@ -909,14 +994,11 @@ void Hex_Dump( void *buffer, size_t len )
       char *buf;
       
       buf = buffer;
-      if ( ( len < 0 ) || ( len > 1000 ) ) {
+      assert( len > 0 );
+      if ( ( len > 1000 ) ) {
          M_print( "Ack!!!!!!  %d\a\n" , len );
 	 return;
       }
-      assert( len > 0 );
-      assert( len < 1000 );
-      if ( len < 0 )
-          return;
       for ( i=0 ; i < len; i++ )
       {
          M_print( "%02x ", ( unsigned char ) buf[i] );
